@@ -6,4 +6,8 @@ utils::globalVariables(c("issue_date", "term_date", "last_date",
                          "ex_wt", "ex2_wt", "is_number", "n_unique",
                          "trx_date", "trx_type", "trx_amt", "trx_n", "trx_flag",
                          "trx_util", "avg_trx", "avg_all", "trx_freq",
-                         "class1", "Series", "Rate", "A/E ratio"))
+                         "class1", "Series", "Rate", "A/E ratio",
+                         "q_obs_lower", "q_obs_upper",
+                         "trx_util_lower", "trx_util_upper", "sd_agg",
+                         "sd_all", "sd_trx", "trx_amt_sq",
+                         "n", "name", "ymax", "ymin"))
